/*



















*/

#version 3.7;

/*

	
	Step 2 of 3, Object To Volume Process (ToVolume)
	Slice.pov
	2013 Sam Benge
 
	This file produces volume data in the form of sequential png files. These can be rendered directly as: isosurfaces; media; other representations....
	
	Depending on the settings used, this file can take quite a while to render completely. Check out some of the tips below.
	
	Directions:
		* scroll down to "begin user-defined settings"
		* set "BlurAmt" and "BlurQualityLevel" to your liking
		* define/include your object and give it the same transformations as the one in "RegisterObject.pov"
		* set some command line options by using the numbers generated by "RegisterObject.pov" as follows:
			* x = image width (+w)
			* y = image height (+h)
			* z = number of frames (+kff)
		* render an animation to save a series of 16-bit png images (see command line options below)
	
	Tips/FYI:
		* for correct results, make sure your object is completely closed
		* if a mesh, make sure your object has no overlapping geometry
		* "BlurAmt" is how much to blur the object pigment, in pixels:
			* more blur = less detail, but more flexibility when displacing the volume later
			* less blur = more detail, but less flexibility when displacing the volume later
		* if you're patient, try setting "BlurQualityLevel" to a high level (up to 5) for best quality (it will take a long time to trace all the frames, but may be worth it to you)
		* for a "preview," try running this file at a low resolution and low number of frames, to make sure everything is working correctly
		* you may not need antialising... so if not, ditch it!
	
	recommended command line options:
		+fn +f +a0.3 +am2 +r3	 +w? +h? +kff? (see below)
	
	bowl settings and stats:
		low-res:
			+fng -f +a0.3 +am2 +r2 +w81 +h68 +kff32
		full-res (this file rendered in 1h 36m 11s on 3 2.4ghz processors, 2GB RAM, using the following command line settings):
			+fng +f +a0.3 +am2 +r2 +w648 +h541 +kff256
			
		
	Final step: IsoRender.pov

*/

// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


//*** begin user-defined settings ***//

#declare BlurAmt					= 2; // amount of blurring, in pixels
#declare BlurQualityLevel	= 1; // proximity quality level: 1 to 5 (1=low)
#declare RemoveOverlap		= true;

#include "bowl_POV_geom.inc" // bowl_mesh_

// must have same transformations as that in "RegisterObject.pov" (Obj)
#declare Obj =
	object{
		bowl_mesh_
		rotate x*270
	}

//*** end user-defined settings ***//


global_settings{assumed_gamma 1.0}

#declare Obj2 =
	object{
		Obj
		translate -min_extent(Obj)
	}

#declare Obj3 =
	object{
		Obj2
		scale 0.5/max_extent(Obj).z
	}

#declare MXE = max_extent(Obj3);

plane{
	z, clock*MXE.z
	#include "Proximity.inc"
	pigment{
		Proximity(Obj3, BlurAmt*MXE.x/image_width, 1)
		#if(RemoveOverlap)
			translate -MXE/2
			scale 1-2*BlurAmt/<image_width, image_height, final_frame>
			translate MXE/2
		#end
		
		//poly_wave 4
	}
	finish{ ambient 1 }
}

camera{
	orthographic
	right x*MXE.x up y*MXE.y
	location -z*2
	look_at z
	translate <MXE.x, MXE.y, 0>/2
}
	

